@@ -47,6 +47,6 @@ class ISocialConfiguration(Interface):
 
     twitter_hashtags = schema.TextLine(
         title=_(u"Twitter Hashtags"),
-        description=_(u"Comma-separated list of hashtags that should be added to a tweet."),
+        description=_(u"Comma-separated list of hashtags (without #) that should be added to a tweet."),
         required=False,
     )
