@@ -13,7 +13,7 @@ def add_button_toggle_configuration(obj):
     obj.enable_linkedin = False
 
 def add_hashtag_configuration(obj):
-    obj.twitter_hashtags = ""
+    obj.twitter_hashtags = u""
 
 
 def upgrade_12_to_14(context, logger=None):
